Method: Zero::Renderer#initialize
- Defined in:
- lib/zero/renderer.rb
#initialize(template_path, type_map = {}) ⇒ Renderer
initializes a new Renderer
This method takes a path to the base template directory and a type map. This type map is used to extend the possible renderings for different types, which the clients sends.
36 37 38 39 |
# File 'lib/zero/renderer.rb', line 36 def initialize(template_path, type_map = {}) @template_path = template_path + '/' @type_map = type_map end |